*;
*  TO DO:
*
*  Line 17: Specifiy the value of the SHEET_INTERVAL option to group 
*           the chart and table of contents in the same sheet.
*
*  Line 67: Specify the value of the SHEET_INTERVAL option to create
*           a new worksheet for each BY group value.
*;

options missing=' ';

ods Excel file="&SAMPDIR\AEResults.xlsx" nogtitle nogfootnote style=HTMLBlue;

*  "Table of Contents" worksheet;

ods Excel options(sheet_name='Table of Contents' sheet_interval='none');

*  Create a chart showing the frequency of the top 15 adverse events;

ods graphics on / reset=all imagefmt=png;

title 'Top 15 Adverse Events';
footnote;

proc sgplot data=sample.ae_topn_summary;
  hbar aedecod / group=aesev
                 response=_frequency_
                 datalabel
                 categoryorder=respdesc;
  yaxis label=' ';
  styleattrs datacolors=(cxa1d99b cxffffb2 cxd95f0e)
             datacontrastcolors=(cxa1d99b cxfe9929 cxd95f0e);
run; quit;

* Create a clickable Table of Contents (TOC);

title;

proc report data=sample.ae_topn_summary split='*' nowd;
  column ('Click term to see detailed data' 
            aedecod aesev _frequency_ _frequency_=percent_of_topn);
  define aedecod         / order    'Dictionary-Derived Term';
  define aesev           / display  'Severity/Intensity';
  define _frequency_     / analysis sum 'Frequency';
  define percent_of_topn / analysis pctsum 'Percent of*Top 15' format=percent8.1;

  *  Create the subtotal and grand total lines;

  break after aedecod / summarize;

  rbreak after / summarize;

  compute aedecod;
    *  Specify labels for the subtotal and grand total lines;
    if (upcase(_break_) eq 'AEDECOD') then aedecod = 'Subtotals';
    else if (_break_ eq '_RBREAK_')   then aedecod = 'Grand Totals';

    *  Placeholder for clickable links;
    if (_break_ eq '') then do;
    end;
  endcomp;
run; quit;

*  Detail data worksheets;

ods Excel options(sheet_name='#byval(aedecod)' sheet_interval='bygroup');

title    link="" '(Click to return to the table of contents)';
footnote link="" '(Click to return to the table of contents)';

proc report data=sample.ae_topn split='*' missing nowd;
  by aedecod;
  column usubjid aesev aerel aestdt_n aeendt_n aeout last_aestdt;
  define usubjid      / order   'Unique Subject*Identifier';
  define aesev        / display 'Severity/*Intensity';
  define aerel        / display 'Causality';
  define aestdt_n     / display 'Start Date/Time*of Adverse Event' format=yymmdd10.;
  define aeendt_n     / display 'End Date/Time*of Adverse Event'   format=yymmdd10.;
  define aeout        / display 'Outcome of*Adverse Event';
  define last_aestdt  / display noprint;

  compute usubjid;
    *  Display the value for the ORDER variable for each row;
    if (usubjid ne '') 
      then temp=usubjid;
      else usubjid=temp;
  endcomp;

  compute last_aestdt;
    *  Placeholder for traffic lighting;
    if (aerel in ('POSSIBLE', 'PROBABLE') and aeout eq 'NOT RESOLVED' and last_aestdt eq 1) then do;
    end;
  endcomp;

  compute after usubjid;
    *  Add white space between subjects;
    line ' ';
  endcomp;
 run; quit;

ods Excel close;

;*';*";*/;quit;run;
* Reference for code above: http://tinyurl.com/mjde9fc ;